dl\_data\_pipeline.process\_functions package
=============================================

Submodules
----------

dl\_data\_pipeline.process\_functions.any\_process module
---------------------------------------------------------

.. automodule:: dl_data_pipeline.process_functions.any_process
   :members:
   :undoc-members:
   :show-inheritance:

dl\_data\_pipeline.process\_functions.process\_1d module
--------------------------------------------------------

.. automodule:: dl_data_pipeline.process_functions.process_1d
   :members:
   :undoc-members:
   :show-inheritance:

dl\_data\_pipeline.process\_functions.process\_2d module
--------------------------------------------------------

.. automodule:: dl_data_pipeline.process_functions.process_2d
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dl_data_pipeline.process_functions
   :members:
   :undoc-members:
   :show-inheritance:
